# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.mongodb.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.mongodb.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.mongodb.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_database__pb2
from yandex.cloud.mdb.mongodb.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_user__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb3_6_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_2_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_4_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_4_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb5_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb5_0_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mongodb/v1/cluster_service.proto',
  package='yandex.cloud.mdb.mongodb.v1',
  syntax='proto3',
  serialized_options=b'\n\037yandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/mdb/mongodb/v1/cluster_service.proto\x12\x1byandex.cloud.mdb.mongodb.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/mdb/mongodb/v1/backup.proto\x1a)yandex/cloud/mdb/mongodb/v1/cluster.proto\x1a*yandex/cloud/mdb/mongodb/v1/database.proto\x1a&yandex/cloud/mdb/mongodb/v1/user.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb3_6.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_0.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_4.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb4_4_enterprise.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb5_0.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb5_0_enterprise.proto\x1a-yandex/cloud/mdb/mongodb/v1/maintenance.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"g\n\x14ListClustersResponse\x12\x36\n\x08\x63lusters\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.mongodb.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x81\x06\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x04name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\r[a-zA-Z0-9_]*\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12K\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x30.yandex.cloud.mdb.mongodb.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x42\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12I\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32).yandex.cloud.mdb.mongodb.v1.DatabaseSpecB\x06\x82\xc8\x31\x02>0\x12\x41\n\nuser_specs\x18\x08 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.UserSpecB\x06\x82\xc8\x31\x02>0\x12\x41\n\nhost_specs\x18\t \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xb6\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12<\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12J\n\x12maintenance_window\x18\x07 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x84\x06\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x04 \x03(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12K\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x30.yandex.cloud.mdb.mongodb.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x42\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12\x41\n\nhost_specs\x18\x07 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x63\n\x14recovery_target_spec\x18\n \x01(\x0b\x32\x45.yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.RecoveryTargetSpec\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\x12RecoveryTargetSpec\x12\x19\n\ttimestamp\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xcc\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12g\n\x0freschedule_type\x18\x02 \x01(\x0e\x32H.yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"f\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb0\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x07message\x18\x02 \x03(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12U\n\x0cservice_type\x18\x03 \x01(\x0e\x32?.yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\"Q\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0c\n\x08MONGOCFG\x10\x03\"h\n\x17ListClusterLogsResponse\x12\x34\n\x04logs\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"d\n\x0fStreamLogRecord\x12\x36\n\x06record\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\x98\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12W\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x41.yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"Q\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0c\n\x08MONGOCFG\x10\x03\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x1aListClusterBackupsResponse\x12\x34\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.mongodb.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"e\n\x18ListClusterHostsResponse\x12\x30\n\x05hosts\x18\x01 \x03(\x0b\x32!.yandex.cloud.mdb.mongodb.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"}\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\nhost_specs\x18\x02 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\xec\x04\n\x1c\x45nableClusterShardingRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12T\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x42.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoCfg\x12P\n\x06mongos\x18\x03 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.Mongos\x12\x41\n\nhost_specs\x18\x04 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12X\n\nmongoinfra\x18\x05 \x01(\x0b\x32\x44.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoInfra\x1aK\n\x08MongoCfg\x12?\n\tresources\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.ResourcesB\x04\xe8\xc7\x31\x01\x1aI\n\x06Mongos\x12?\n\tresources\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.ResourcesB\x04\xe8\xc7\x31\x01\x1aM\n\nMongoInfra\x12?\n\tresources\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.ResourcesB\x04\xe8\xc7\x31\x01\"3\n\x1d\x45nableClusterShardingMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"n\n\x16GetClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"z\n\x18ListClusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x19ListClusterShardsResponse\x12\x32\n\x06shards\x18\x01 \x03(\x0b\x32\".yandex.cloud.mdb.mongodb.v1.Shard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb1\x01\n\x16\x41\x64\x64\x43lusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x41\n\nhost_specs\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"q\n\x19\x44\x65leteClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"D\n\x1a\x44\x65leteClusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"\\\n\x13ResetupHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\">\n\x14ResetupHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\\\n\x13RestartHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\">\n\x14RestartHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"]\n\x14StepdownHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"?\n\x15StepdownHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\xc2\x01\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12\x34\n\x04type\x18\x04 \x01(\x0e\x32&.yandex.cloud.mdb.mongodb.v1.Host.Type\x12.\n\nshard_name\x18\x05 \x01(\tB\x1a\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"\xb7\x07\n\x0eMongodbSpec3_6\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra\x1a\x88\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8c\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x88\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe3\x01\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig3_6\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig3_6\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb7\x07\n\x0eMongodbSpec4_0\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra\x1a\x88\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8c\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x88\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe3\x01\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_0\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb7\x07\n\x0eMongodbSpec4_2\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra\x1a\x88\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8c\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x88\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe3\x01\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb7\x07\n\x0eMongodbSpec4_4\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra\x1a\x88\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8c\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x88\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe3\x01\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xa5\x08\n\x19MongodbSpec4_4_enterprise\x12M\n\x06mongod\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongod\x12Q\n\x08mongocfg\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoCfg\x12M\n\x06mongos\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongos\x12U\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra\x1a\x93\x01\n\x06Mongod\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x97\x01\n\x08MongoCfg\x12P\n\x06\x63onfig\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x93\x01\n\x06Mongos\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xf9\x01\n\nMongoInfra\x12U\n\rconfig_mongos\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4_enterprise\x12Y\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb7\x07\n\x0eMongodbSpec5_0\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra\x1a\x88\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8c\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x88\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe3\x01\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xa5\x08\n\x19MongodbSpec5_0_enterprise\x12M\n\x06mongod\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongod\x12Q\n\x08mongocfg\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoCfg\x12M\n\x06mongos\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongos\x12U\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra\x1a\x93\x01\n\x06Mongod\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x97\x01\n\x08MongoCfg\x12P\n\x06\x63onfig\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x93\x01\n\x06Mongos\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xf9\x01\n\nMongoInfra\x12U\n\rconfig_mongos\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0_enterprise\x12Y\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xc0\x07\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12%\n\x1d\x66\x65\x61ture_compatibility_version\x18\x05 \x01(\t\x12X\n\x10mongodb_spec_3_6\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6H\x00R\x0fmongodbSpec_3_6\x12X\n\x10mongodb_spec_4_0\x18\x04 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0H\x00R\x0fmongodbSpec_4_0\x12X\n\x10mongodb_spec_4_2\x18\x07 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2H\x00R\x0fmongodbSpec_4_2\x12X\n\x10mongodb_spec_4_4\x18\x08 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4H\x00R\x0fmongodbSpec_4_4\x12X\n\x10mongodb_spec_5_0\x18\n \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0H\x00R\x0fmongodbSpec_5_0\x12y\n\x1bmongodb_spec_4_4_enterprise\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterpriseH\x00R\x1amongodbSpec_4_4_enterprise\x12y\n\x1bmongodb_spec_5_0_enterprise\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterpriseH\x00R\x1amongodbSpec_5_0_enterprise\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x03 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x37-35\x12\x33\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32#.yandex.cloud.mdb.mongodb.v1.AccessB\x0e\n\x0cmongodb_spec2\xf6\'\n\x0e\x43lusterService\x12\x8e\x01\n\x03Get\x12..yandex.cloud.mdb.mongodb.v1.GetClusterRequest\x1a$.yandex.cloud.mdb.mongodb.v1.Cluster\"1\x82\xd3\xe4\x93\x02+\x12)/managed-mongodb/v1/clusters/{cluster_id}\x12\x91\x01\n\x04List\x12\x30.yandex.cloud.mdb.mongodb.v1.ListClustersRequest\x1a\x31.yandex.cloud.mdb.mongodb.v1.ListClustersResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-mongodb/v1/clusters\x12\xab\x01\n\x06\x43reate\x12\x31.yandex.cloud.mdb.mongodb.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"K\x82\xd3\xe4\x93\x02!\"\x1c/managed-mongodb/v1/clusters:\x01*\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x12\xb8\x01\n\x06Update\x12\x31.yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02.2)/managed-mongodb/v1/clusters/{cluster_id}:\x01*\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x12\xc3\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.mdb.mongodb.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02+*)/managed-mongodb/v1/clusters/{cluster_id}\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x12\xb8\x01\n\x05Start\x12\x30.yandex.cloud.mdb.mongodb.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02\x31\"//managed-mongodb/v1/clusters/{cluster_id}:start\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x12\xb4\x01\n\x04Stop\x12/.yandex.cloud.mdb.mongodb.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02\x30\"./managed-mongodb/v1/clusters/{cluster_id}:stop\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x12\xb7\x01\n\x04Move\x12/.yandex.cloud.mdb.mongodb.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02\x33\"./managed-mongodb/v1/clusters/{cluster_id}:move:\x01*\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x12\xbc\x01\n\x06\x42\x61\x63kup\x12\x31.yandex.cloud.mdb.mongodb.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\x82\xd3\xe4\x93\x02\x32\"0/managed-mongodb/v1/clusters/{cluster_id}:backup\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x12\xb6\x01\n\x07Restore\x12\x32.yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02)\"$/managed-mongodb/v1/clusters:restore:\x01*\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x12\xed\x01\n\x15RescheduleMaintenance\x12\x39.yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"v\x82\xd3\xe4\x93\x02\x44\"?/managed-mongodb/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x12\xad\x01\n\x08ListLogs\x12\x33.yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest\x1a\x34.yandex.cloud.mdb.mongodb.v1.ListClusterLogsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-mongodb/v1/clusters/{cluster_id}:logs\x12\xb2\x01\n\nStreamLogs\x12\x35.yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest\x1a,.yandex.cloud.mdb.mongodb.v1.StreamLogRecord\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-mongodb/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xc5\x01\n\x0eListOperations\x12\x39.yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest\x1a:.yandex.cloud.mdb.mongodb.v1.ListClusterOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-mongodb/v1/clusters/{cluster_id}/operations\x12\xb9\x01\n\x0bListBackups\x12\x36.yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest\x1a\x37.yandex.cloud.mdb.mongodb.v1.ListClusterBackupsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-mongodb/v1/clusters/{cluster_id}/backups\x12\xb1\x01\n\tListHosts\x12\x34.yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest\x1a\x35.yandex.cloud.mdb.mongodb.v1.ListClusterHostsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//managed-mongodb/v1/clusters/{cluster_id}/hosts\x12\xde\x01\n\x08\x41\x64\x64Hosts\x12\x33.yandex.cloud.mdb.mongodb.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"z\x82\xd3\xe4\x93\x02@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x12\xe7\x01\n\x0b\x44\x65leteHosts\x12\x36.yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"}\x82\xd3\xe4\x93\x02@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x12\xed\x01\n\x0e\x45nableSharding\x12\x39.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest\x1a!.yandex.cloud.operation.Operation\"}\x82\xd3\xe4\x93\x02=\"8/managed-mongodb/v1/clusters/{cluster_id}:enableSharding:\x01*\xb2\xd2*6\n\x1d\x45nableClusterShardingMetadata\x12\x15google.protobuf.Empty\x12\xaa\x01\n\x08GetShard\x12\x33.yandex.cloud.mdb.mongodb.v1.GetClusterShardRequest\x1a\".yandex.cloud.mdb.mongodb.v1.Shard\"E\x82\xd3\xe4\x93\x02?\x12=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xb5\x01\n\nListShards\x12\x35.yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest\x1a\x36.yandex.cloud.mdb.mongodb.v1.ListClusterShardsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-mongodb/v1/clusters/{cluster_id}/shards\x12\xc3\x01\n\x08\x41\x64\x64Shard\x12\x33.yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"_\x82\xd3\xe4\x93\x02\x35\"0/managed-mongodb/v1/clusters/{cluster_id}/shards:\x01*\xb2\xd2* \n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x05Shard\x12\xe6\x01\n\x0b\x44\x65leteShard\x12\x36.yandex.cloud.mdb.mongodb.v1.DeleteClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"|\x82\xd3\xe4\x93\x02?*=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}\xb2\xd2*3\n\x1a\x44\x65leteClusterShardMetadata\x12\x15google.protobuf.Empty\x12\xd7\x01\n\x0cResetupHosts\x12\x30.yandex.cloud.mdb.mongodb.v1.ResetupHostsRequest\x1a!.yandex.cloud.operation.Operation\"r\x82\xd3\xe4\x93\x02;\"6/managed-mongodb/v1/clusters/{cluster_id}:resetupHosts:\x01*\xb2\xd2*-\n\x14ResetupHostsMetadata\x12\x15google.protobuf.Empty\x12\xd7\x01\n\x0cRestartHosts\x12\x30.yandex.cloud.mdb.mongodb.v1.RestartHostsRequest\x1a!.yandex.cloud.operation.Operation\"r\x82\xd3\xe4\x93\x02;\"6/managed-mongodb/v1/clusters/{cluster_id}:restartHosts:\x01*\xb2\xd2*-\n\x14RestartHostsMetadata\x12\x15google.protobuf.Empty\x12\xdb\x01\n\rStepdownHosts\x12\x31.yandex.cloud.mdb.mongodb.v1.StepdownHostsRequest\x1a!.yandex.cloud.operation.Operation\"t\x82\xd3\xe4\x93\x02<\"7/managed-mongodb/v1/clusters/{cluster_id}:stepdownHosts:\x01*\xb2\xd2*.\n\x15StepdownHostsMetadata\x12\x15google.protobuf.EmptyBj\n\x1fyandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodbb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_type_dot_timeofday__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_backup__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_database__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_user__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_maintenance__pb2.DESCRIPTOR,])



_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE = _descriptor.EnumDescriptor(
  name='RescheduleType',
  full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest.RescheduleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESCHEDULE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEXT_AVAILABLE_WINDOW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPECIFIC_TIME', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4362,
  serialized_end=4472,
)
_sym_db.RegisterEnumDescriptor(_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE)

_LISTCLUSTERLOGSREQUEST_SERVICETYPE = _descriptor.EnumDescriptor(
  name='ServiceType',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.ServiceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVICE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONGOD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONGOS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONGOCFG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5082,
  serialized_end=5163,
)
_sym_db.RegisterEnumDescriptor(_LISTCLUSTERLOGSREQUEST_SERVICETYPE)

_STREAMCLUSTERLOGSREQUEST_SERVICETYPE = _descriptor.EnumDescriptor(
  name='ServiceType',
  full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.ServiceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVICE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONGOD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONGOS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONGOCFG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5082,
  serialized_end=5163,
)
_sym_db.RegisterEnumDescriptor(_STREAMCLUSTERLOGSREQUEST_SERVICETYPE)


_GETCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.GetClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.GetClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=1007,
)


_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListClustersRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.mdb.mongodb.v1.ListClustersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.mongodb.v1.ListClustersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.mdb.mongodb.v1.ListClustersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1010,
  serialized_end=1154,
)


_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListClustersResponse',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='yandex.cloud.mdb.mongodb.v1.ListClustersResponse.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1259,
)


_CREATECLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2031,
)

_CREATECLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\r[a-zA-Z0-9_]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.environment', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_spec', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.config_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_specs', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.database_specs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_specs', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.user_specs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_specs', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.host_specs', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.network_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.security_group_ids', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.deletion_protection', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=2031,
)


_CREATECLUSTERMETADATA = _descriptor.Descriptor(
  name='CreateClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.CreateClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2033,
  serialized_end=2076,
)


_UPDATECLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2031,
)

_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_spec', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.config_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_window', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.maintenance_window', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.security_group_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.deletion_protection', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2079,
  serialized_end=2645,
)


_UPDATECLUSTERMETADATA = _descriptor.Descriptor(
  name='UpdateClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.UpdateClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2690,
)


_DELETECLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2748,
)


_DELETECLUSTERMETADATA = _descriptor.Descriptor(
  name='DeleteClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2750,
  serialized_end=2793,
)


_STARTCLUSTERREQUEST = _descriptor.Descriptor(
  name='StartClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.StartClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StartClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2850,
)


_STARTCLUSTERMETADATA = _descriptor.Descriptor(
  name='StartClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.StartClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StartClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2852,
  serialized_end=2894,
)


_STOPCLUSTERREQUEST = _descriptor.Descriptor(
  name='StopClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.StopClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StopClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2896,
  serialized_end=2950,
)


_STOPCLUSTERMETADATA = _descriptor.Descriptor(
  name='StopClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.StopClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StopClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2952,
  serialized_end=2993,
)


_MOVECLUSTERREQUEST = _descriptor.Descriptor(
  name='MoveClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2995,
  serialized_end=3094,
)


_MOVECLUSTERMETADATA = _descriptor.Descriptor(
  name='MoveClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_folder_id', full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterMetadata.source_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.mdb.mongodb.v1.MoveClusterMetadata.destination_folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3096,
  serialized_end=3194,
)


_BACKUPCLUSTERREQUEST = _descriptor.Descriptor(
  name='BackupClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.BackupClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.BackupClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3196,
  serialized_end=3252,
)


_BACKUPCLUSTERMETADATA = _descriptor.Descriptor(
  name='BackupClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.BackupClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.BackupClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3254,
  serialized_end=3297,
)


_RESTORECLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2031,
)

_RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC = _descriptor.Descriptor(
  name='RecoveryTargetSpec',
  full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.RecoveryTargetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.RecoveryTargetSpec.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4025,
  serialized_end=4072,
)

_RESTORECLUSTERREQUEST = _descriptor.Descriptor(
  name='RestoreClusterRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.backup_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.environment', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_spec', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.config_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_specs', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.host_specs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.network_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.folder_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recovery_target_spec', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.recovery_target_spec', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.security_group_ids', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESTORECLUSTERREQUEST_LABELSENTRY, _RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3300,
  serialized_end=4072,
)


_RESTORECLUSTERMETADATA = _descriptor.Descriptor(
  name='RestoreClusterMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.mdb.mongodb.v1.RestoreClusterMetadata.backup_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4074,
  serialized_end=4137,
)


_RESCHEDULEMAINTENANCEREQUEST = _descriptor.Descriptor(
  name='RescheduleMaintenanceRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reschedule_type', full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest.reschedule_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_until', full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest.delayed_until', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4140,
  serialized_end=4472,
)


_RESCHEDULEMAINTENANCEMETADATA = _descriptor.Descriptor(
  name='RescheduleMaintenanceMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_until', full_name='yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceMetadata.delayed_until', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4474,
  serialized_end=4576,
)


_LOGRECORD_MESSAGEENTRY = _descriptor.Descriptor(
  name='MessageEntry',
  full_name='yandex.cloud.mdb.mongodb.v1.LogRecord.MessageEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.mongodb.v1.LogRecord.MessageEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.mongodb.v1.LogRecord.MessageEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4709,
  serialized_end=4755,
)

_LOGRECORD = _descriptor.Descriptor(
  name='LogRecord',
  full_name='yandex.cloud.mdb.mongodb.v1.LogRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='yandex.cloud.mdb.mongodb.v1.LogRecord.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='yandex.cloud.mdb.mongodb.v1.LogRecord.message', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGRECORD_MESSAGEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4579,
  serialized_end=4755,
)


_LISTCLUSTERLOGSREQUEST = _descriptor.Descriptor(
  name='ListClusterLogsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_filter', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.column_filter', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_type', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.service_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.from_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_time', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.to_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.page_size', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.page_token', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LISTCLUSTERLOGSREQUEST_SERVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4758,
  serialized_end=5163,
)


_LISTCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
  name='ListClusterLogsResponse',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsResponse.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterLogsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5165,
  serialized_end=5269,
)


_STREAMLOGRECORD = _descriptor.Descriptor(
  name='StreamLogRecord',
  full_name='yandex.cloud.mdb.mongodb.v1.StreamLogRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='yandex.cloud.mdb.mongodb.v1.StreamLogRecord.record', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_record_token', full_name='yandex.cloud.mdb.mongodb.v1.StreamLogRecord.next_record_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5271,
  serialized_end=5371,
)


_STREAMCLUSTERLOGSREQUEST = _descriptor.Descriptor(
  name='StreamClusterLogsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_filter', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.column_filter', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_type', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.service_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.from_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_time', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.to_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record_token', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.record_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.filter', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMCLUSTERLOGSREQUEST_SERVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5374,
  serialized_end=5782,
)


_LISTCLUSTEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListClusterOperationsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5784,
  serialized_end=5910,
)


_LISTCLUSTEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListClusterOperationsResponse',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5912,
  serialized_end=6023,
)


_LISTCLUSTERBACKUPSREQUEST = _descriptor.Descriptor(
  name='ListClusterBackupsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6025,
  serialized_end=6148,
)


_LISTCLUSTERBACKUPSRESPONSE = _descriptor.Descriptor(
  name='ListClusterBackupsResponse',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backups', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsResponse.backups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterBackupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6150,
  serialized_end=6257,
)


_LISTCLUSTERHOSTSREQUEST = _descriptor.Descriptor(
  name='ListClusterHostsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6259,
  serialized_end=6380,
)


_LISTCLUSTERHOSTSRESPONSE = _descriptor.Descriptor(
  name='ListClusterHostsResponse',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsResponse.hosts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterHostsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6382,
  serialized_end=6483,
)


_ADDCLUSTERHOSTSREQUEST = _descriptor.Descriptor(
  name='AddClusterHostsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.AddClusterHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_specs', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterHostsRequest.host_specs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6485,
  serialized_end=6610,
)


_ADDCLUSTERHOSTSMETADATA = _descriptor.Descriptor(
  name='AddClusterHostsMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.AddClusterHostsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterHostsMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterHostsMetadata.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6612,
  serialized_end=6677,
)


_DELETECLUSTERHOSTSREQUEST = _descriptor.Descriptor(
  name='DeleteClusterHostsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsRequest.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\212\3101\005<=253', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6679,
  serialized_end=6777,
)


_DELETECLUSTERHOSTSMETADATA = _descriptor.Descriptor(
  name='DeleteClusterHostsMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsMetadata.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6779,
  serialized_end=6847,
)


_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoCfg.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7241,
  serialized_end=7316,
)

_ENABLECLUSTERSHARDINGREQUEST_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.Mongos.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7318,
  serialized_end=7391,
)

_ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoInfra.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7393,
  serialized_end=7470,
)

_ENABLECLUSTERSHARDINGREQUEST = _descriptor.Descriptor(
  name='EnableClusterShardingRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_specs', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.host_specs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.mongoinfra', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG, _ENABLECLUSTERSHARDINGREQUEST_MONGOS, _ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6850,
  serialized_end=7470,
)


_ENABLECLUSTERSHARDINGMETADATA = _descriptor.Descriptor(
  name='EnableClusterShardingMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.EnableClusterShardingMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7472,
  serialized_end=7523,
)


_GETCLUSTERSHARDREQUEST = _descriptor.Descriptor(
  name='GetClusterShardRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.GetClusterShardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.GetClusterShardRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.mdb.mongodb.v1.GetClusterShardRequest.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7525,
  serialized_end=7635,
)


_LISTCLUSTERSHARDSREQUEST = _descriptor.Descriptor(
  name='ListClusterShardsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7637,
  serialized_end=7759,
)


_LISTCLUSTERSHARDSRESPONSE = _descriptor.Descriptor(
  name='ListClusterShardsResponse',
  full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shards', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsResponse.shards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.mongodb.v1.ListClusterShardsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7761,
  serialized_end=7865,
)


_ADDCLUSTERSHARDREQUEST = _descriptor.Descriptor(
  name='AddClusterShardRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_specs', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest.host_specs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7868,
  serialized_end=8045,
)


_ADDCLUSTERSHARDMETADATA = _descriptor.Descriptor(
  name='AddClusterShardMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.mdb.mongodb.v1.AddClusterShardMetadata.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8047,
  serialized_end=8112,
)


_DELETECLUSTERSHARDREQUEST = _descriptor.Descriptor(
  name='DeleteClusterShardRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterShardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterShardRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterShardRequest.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8114,
  serialized_end=8227,
)


_DELETECLUSTERSHARDMETADATA = _descriptor.Descriptor(
  name='DeleteClusterShardMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterShardMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterShardMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.mdb.mongodb.v1.DeleteClusterShardMetadata.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8229,
  serialized_end=8297,
)


_RESETUPHOSTSREQUEST = _descriptor.Descriptor(
  name='ResetupHostsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.ResetupHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ResetupHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.ResetupHostsRequest.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\212\3101\005<=253', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8299,
  serialized_end=8391,
)


_RESETUPHOSTSMETADATA = _descriptor.Descriptor(
  name='ResetupHostsMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.ResetupHostsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.ResetupHostsMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.ResetupHostsMetadata.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8393,
  serialized_end=8455,
)


_RESTARTHOSTSREQUEST = _descriptor.Descriptor(
  name='RestartHostsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.RestartHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.RestartHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.RestartHostsRequest.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\212\3101\005<=253', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8457,
  serialized_end=8549,
)


_RESTARTHOSTSMETADATA = _descriptor.Descriptor(
  name='RestartHostsMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.RestartHostsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.RestartHostsMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.RestartHostsMetadata.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8551,
  serialized_end=8613,
)


_STEPDOWNHOSTSREQUEST = _descriptor.Descriptor(
  name='StepdownHostsRequest',
  full_name='yandex.cloud.mdb.mongodb.v1.StepdownHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StepdownHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.StepdownHostsRequest.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\212\3101\005<=253', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8615,
  serialized_end=8708,
)


_STEPDOWNHOSTSMETADATA = _descriptor.Descriptor(
  name='StepdownHostsMetadata',
  full_name='yandex.cloud.mdb.mongodb.v1.StepdownHostsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mongodb.v1.StepdownHostsMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_names', full_name='yandex.cloud.mdb.mongodb.v1.StepdownHostsMetadata.host_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8710,
  serialized_end=8773,
)


_HOSTSPEC = _descriptor.Descriptor(
  name='HostSpec',
  full_name='yandex.cloud.mdb.mongodb.v1.HostSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.mdb.mongodb.v1.HostSpec.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.mdb.mongodb.v1.HostSpec.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ip', full_name='yandex.cloud.mdb.mongodb.v1.HostSpec.assign_public_ip', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.mdb.mongodb.v1.HostSpec.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.mdb.mongodb.v1.HostSpec.shard_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8776,
  serialized_end=8970,
)


_MONGODBSPEC3_6_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9276,
  serialized_end=9412,
)

_MONGODBSPEC3_6_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9415,
  serialized_end=9555,
)

_MONGODBSPEC3_6_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9558,
  serialized_end=9694,
)

_MONGODBSPEC3_6_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9697,
  serialized_end=9924,
)

_MONGODBSPEC3_6 = _descriptor.Descriptor(
  name='MongodbSpec3_6',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC3_6_MONGOD, _MONGODBSPEC3_6_MONGOCFG, _MONGODBSPEC3_6_MONGOS, _MONGODBSPEC3_6_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8973,
  serialized_end=9924,
)


_MONGODBSPEC4_0_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10230,
  serialized_end=10366,
)

_MONGODBSPEC4_0_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10369,
  serialized_end=10509,
)

_MONGODBSPEC4_0_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10512,
  serialized_end=10648,
)

_MONGODBSPEC4_0_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10651,
  serialized_end=10878,
)

_MONGODBSPEC4_0 = _descriptor.Descriptor(
  name='MongodbSpec4_0',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC4_0_MONGOD, _MONGODBSPEC4_0_MONGOCFG, _MONGODBSPEC4_0_MONGOS, _MONGODBSPEC4_0_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9927,
  serialized_end=10878,
)


_MONGODBSPEC4_2_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11184,
  serialized_end=11320,
)

_MONGODBSPEC4_2_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11323,
  serialized_end=11463,
)

_MONGODBSPEC4_2_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11466,
  serialized_end=11602,
)

_MONGODBSPEC4_2_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11605,
  serialized_end=11832,
)

_MONGODBSPEC4_2 = _descriptor.Descriptor(
  name='MongodbSpec4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC4_2_MONGOD, _MONGODBSPEC4_2_MONGOCFG, _MONGODBSPEC4_2_MONGOS, _MONGODBSPEC4_2_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10881,
  serialized_end=11832,
)


_MONGODBSPEC4_4_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12138,
  serialized_end=12274,
)

_MONGODBSPEC4_4_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12277,
  serialized_end=12417,
)

_MONGODBSPEC4_4_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12420,
  serialized_end=12556,
)

_MONGODBSPEC4_4_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12559,
  serialized_end=12786,
)

_MONGODBSPEC4_4 = _descriptor.Descriptor(
  name='MongodbSpec4_4',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC4_4_MONGOD, _MONGODBSPEC4_4_MONGOCFG, _MONGODBSPEC4_4_MONGOS, _MONGODBSPEC4_4_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11835,
  serialized_end=12786,
)


_MONGODBSPEC4_4_ENTERPRISE_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13147,
  serialized_end=13294,
)

_MONGODBSPEC4_4_ENTERPRISE_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13297,
  serialized_end=13448,
)

_MONGODBSPEC4_4_ENTERPRISE_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13451,
  serialized_end=13598,
)

_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13601,
  serialized_end=13850,
)

_MONGODBSPEC4_4_ENTERPRISE = _descriptor.Descriptor(
  name='MongodbSpec4_4_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC4_4_ENTERPRISE_MONGOD, _MONGODBSPEC4_4_ENTERPRISE_MONGOCFG, _MONGODBSPEC4_4_ENTERPRISE_MONGOS, _MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12789,
  serialized_end=13850,
)


_MONGODBSPEC5_0_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14156,
  serialized_end=14292,
)

_MONGODBSPEC5_0_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14295,
  serialized_end=14435,
)

_MONGODBSPEC5_0_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14438,
  serialized_end=14574,
)

_MONGODBSPEC5_0_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14577,
  serialized_end=14804,
)

_MONGODBSPEC5_0 = _descriptor.Descriptor(
  name='MongodbSpec5_0',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC5_0_MONGOD, _MONGODBSPEC5_0_MONGOCFG, _MONGODBSPEC5_0_MONGOS, _MONGODBSPEC5_0_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13853,
  serialized_end=14804,
)


_MONGODBSPEC5_0_ENTERPRISE_MONGOD = _descriptor.Descriptor(
  name='Mongod',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongod.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongod.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15165,
  serialized_end=15312,
)

_MONGODBSPEC5_0_ENTERPRISE_MONGOCFG = _descriptor.Descriptor(
  name='MongoCfg',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoCfg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoCfg.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoCfg.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15315,
  serialized_end=15466,
)

_MONGODBSPEC5_0_ENTERPRISE_MONGOS = _descriptor.Descriptor(
  name='Mongos',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongos.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongos.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15469,
  serialized_end=15616,
)

_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA = _descriptor.Descriptor(
  name='MongoInfra',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra.config_mongos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra.config_mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15619,
  serialized_end=15868,
)

_MONGODBSPEC5_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongodbSpec5_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mongod', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.mongod', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongocfg', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.mongocfg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongos', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.mongos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongoinfra', full_name='yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.mongoinfra', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODBSPEC5_0_ENTERPRISE_MONGOD, _MONGODBSPEC5_0_ENTERPRISE_MONGOCFG, _MONGODBSPEC5_0_ENTERPRISE_MONGOS, _MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14807,
  serialized_end=15868,
)


_CONFIGSPEC = _descriptor.Descriptor(
  name='ConfigSpec',
  full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_compatibility_version', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.feature_compatibility_version', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_3_6', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_3_6', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_3_6', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_4_0', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_4_0', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_4_0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_4_2', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_4_2', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_4_2', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_4_4', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_4_4', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_4_4', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_5_0', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_5_0', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_5_0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_4_4_enterprise', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_4_4_enterprise', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_4_4_enterprise', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mongodb_spec_5_0_enterprise', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec_5_0_enterprise', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mongodbSpec_5_0_enterprise', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_window_start', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.backup_window_start', index=9,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_retain_period_days', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.backup_retain_period_days', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0047-35', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.access', index=11,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mongodb_spec', full_name='yandex.cloud.mdb.mongodb.v1.ConfigSpec.mongodb_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=15871,
  serialized_end=16831,
)

_LISTCLUSTERSRESPONSE.fields_by_name['clusters'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._CLUSTER
_CREATECLUSTERREQUEST_LABELSENTRY.containing_type = _CREATECLUSTERREQUEST
_CREATECLUSTERREQUEST.fields_by_name['labels'].message_type = _CREATECLUSTERREQUEST_LABELSENTRY
_CREATECLUSTERREQUEST.fields_by_name['environment'].enum_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._CLUSTER_ENVIRONMENT
_CREATECLUSTERREQUEST.fields_by_name['config_spec'].message_type = _CONFIGSPEC
_CREATECLUSTERREQUEST.fields_by_name['database_specs'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_database__pb2._DATABASESPEC
_CREATECLUSTERREQUEST.fields_by_name['user_specs'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_user__pb2._USERSPEC
_CREATECLUSTERREQUEST.fields_by_name['host_specs'].message_type = _HOSTSPEC
_UPDATECLUSTERREQUEST_LABELSENTRY.containing_type = _UPDATECLUSTERREQUEST
_UPDATECLUSTERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECLUSTERREQUEST.fields_by_name['labels'].message_type = _UPDATECLUSTERREQUEST_LABELSENTRY
_UPDATECLUSTERREQUEST.fields_by_name['config_spec'].message_type = _CONFIGSPEC
_UPDATECLUSTERREQUEST.fields_by_name['maintenance_window'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_maintenance__pb2._MAINTENANCEWINDOW
_RESTORECLUSTERREQUEST_LABELSENTRY.containing_type = _RESTORECLUSTERREQUEST
_RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC.containing_type = _RESTORECLUSTERREQUEST
_RESTORECLUSTERREQUEST.fields_by_name['labels'].message_type = _RESTORECLUSTERREQUEST_LABELSENTRY
_RESTORECLUSTERREQUEST.fields_by_name['environment'].enum_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._CLUSTER_ENVIRONMENT
_RESTORECLUSTERREQUEST.fields_by_name['config_spec'].message_type = _CONFIGSPEC
_RESTORECLUSTERREQUEST.fields_by_name['host_specs'].message_type = _HOSTSPEC
_RESTORECLUSTERREQUEST.fields_by_name['recovery_target_spec'].message_type = _RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type'].enum_type = _RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['delayed_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE.containing_type = _RESCHEDULEMAINTENANCEREQUEST
_RESCHEDULEMAINTENANCEMETADATA.fields_by_name['delayed_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGRECORD_MESSAGEENTRY.containing_type = _LOGRECORD
_LOGRECORD.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGRECORD.fields_by_name['message'].message_type = _LOGRECORD_MESSAGEENTRY
_LISTCLUSTERLOGSREQUEST.fields_by_name['service_type'].enum_type = _LISTCLUSTERLOGSREQUEST_SERVICETYPE
_LISTCLUSTERLOGSREQUEST.fields_by_name['from_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCLUSTERLOGSREQUEST.fields_by_name['to_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCLUSTERLOGSREQUEST_SERVICETYPE.containing_type = _LISTCLUSTERLOGSREQUEST
_LISTCLUSTERLOGSRESPONSE.fields_by_name['logs'].message_type = _LOGRECORD
_STREAMLOGRECORD.fields_by_name['record'].message_type = _LOGRECORD
_STREAMCLUSTERLOGSREQUEST.fields_by_name['service_type'].enum_type = _STREAMCLUSTERLOGSREQUEST_SERVICETYPE
_STREAMCLUSTERLOGSREQUEST.fields_by_name['from_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCLUSTERLOGSREQUEST.fields_by_name['to_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCLUSTERLOGSREQUEST_SERVICETYPE.containing_type = _STREAMCLUSTERLOGSREQUEST
_LISTCLUSTEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTCLUSTERBACKUPSRESPONSE.fields_by_name['backups'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_backup__pb2._BACKUP
_LISTCLUSTERHOSTSRESPONSE.fields_by_name['hosts'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._HOST
_ADDCLUSTERHOSTSREQUEST.fields_by_name['host_specs'].message_type = _HOSTSPEC
_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG.containing_type = _ENABLECLUSTERSHARDINGREQUEST
_ENABLECLUSTERSHARDINGREQUEST_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_ENABLECLUSTERSHARDINGREQUEST_MONGOS.containing_type = _ENABLECLUSTERSHARDINGREQUEST
_ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA.containing_type = _ENABLECLUSTERSHARDINGREQUEST
_ENABLECLUSTERSHARDINGREQUEST.fields_by_name['mongocfg'].message_type = _ENABLECLUSTERSHARDINGREQUEST_MONGOCFG
_ENABLECLUSTERSHARDINGREQUEST.fields_by_name['mongos'].message_type = _ENABLECLUSTERSHARDINGREQUEST_MONGOS
_ENABLECLUSTERSHARDINGREQUEST.fields_by_name['host_specs'].message_type = _HOSTSPEC
_ENABLECLUSTERSHARDINGREQUEST.fields_by_name['mongoinfra'].message_type = _ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA
_LISTCLUSTERSHARDSRESPONSE.fields_by_name['shards'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._SHARD
_ADDCLUSTERSHARDREQUEST.fields_by_name['host_specs'].message_type = _HOSTSPEC
_HOSTSPEC.fields_by_name['type'].enum_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._HOST_TYPE
_MONGODBSPEC3_6_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2._MONGODCONFIG3_6
_MONGODBSPEC3_6_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC3_6_MONGOD.containing_type = _MONGODBSPEC3_6
_MONGODBSPEC3_6_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2._MONGOCFGCONFIG3_6
_MONGODBSPEC3_6_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC3_6_MONGOCFG.containing_type = _MONGODBSPEC3_6
_MONGODBSPEC3_6_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2._MONGOSCONFIG3_6
_MONGODBSPEC3_6_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC3_6_MONGOS.containing_type = _MONGODBSPEC3_6
_MONGODBSPEC3_6_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2._MONGOSCONFIG3_6
_MONGODBSPEC3_6_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2._MONGOCFGCONFIG3_6
_MONGODBSPEC3_6_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC3_6_MONGOINFRA.containing_type = _MONGODBSPEC3_6
_MONGODBSPEC3_6.fields_by_name['mongod'].message_type = _MONGODBSPEC3_6_MONGOD
_MONGODBSPEC3_6.fields_by_name['mongocfg'].message_type = _MONGODBSPEC3_6_MONGOCFG
_MONGODBSPEC3_6.fields_by_name['mongos'].message_type = _MONGODBSPEC3_6_MONGOS
_MONGODBSPEC3_6.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC3_6_MONGOINFRA
_MONGODBSPEC4_0_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2._MONGODCONFIG4_0
_MONGODBSPEC4_0_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_0_MONGOD.containing_type = _MONGODBSPEC4_0
_MONGODBSPEC4_0_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2._MONGOCFGCONFIG4_0
_MONGODBSPEC4_0_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_0_MONGOCFG.containing_type = _MONGODBSPEC4_0
_MONGODBSPEC4_0_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2._MONGOSCONFIG4_0
_MONGODBSPEC4_0_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_0_MONGOS.containing_type = _MONGODBSPEC4_0
_MONGODBSPEC4_0_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2._MONGOSCONFIG4_0
_MONGODBSPEC4_0_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2._MONGOCFGCONFIG4_0
_MONGODBSPEC4_0_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_0_MONGOINFRA.containing_type = _MONGODBSPEC4_0
_MONGODBSPEC4_0.fields_by_name['mongod'].message_type = _MONGODBSPEC4_0_MONGOD
_MONGODBSPEC4_0.fields_by_name['mongocfg'].message_type = _MONGODBSPEC4_0_MONGOCFG
_MONGODBSPEC4_0.fields_by_name['mongos'].message_type = _MONGODBSPEC4_0_MONGOS
_MONGODBSPEC4_0.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC4_0_MONGOINFRA
_MONGODBSPEC4_2_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2._MONGODCONFIG4_2
_MONGODBSPEC4_2_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_2_MONGOD.containing_type = _MONGODBSPEC4_2
_MONGODBSPEC4_2_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2._MONGOCFGCONFIG4_2
_MONGODBSPEC4_2_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_2_MONGOCFG.containing_type = _MONGODBSPEC4_2
_MONGODBSPEC4_2_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2._MONGOSCONFIG4_2
_MONGODBSPEC4_2_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_2_MONGOS.containing_type = _MONGODBSPEC4_2
_MONGODBSPEC4_2_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2._MONGOSCONFIG4_2
_MONGODBSPEC4_2_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2._MONGOCFGCONFIG4_2
_MONGODBSPEC4_2_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_2_MONGOINFRA.containing_type = _MONGODBSPEC4_2
_MONGODBSPEC4_2.fields_by_name['mongod'].message_type = _MONGODBSPEC4_2_MONGOD
_MONGODBSPEC4_2.fields_by_name['mongocfg'].message_type = _MONGODBSPEC4_2_MONGOCFG
_MONGODBSPEC4_2.fields_by_name['mongos'].message_type = _MONGODBSPEC4_2_MONGOS
_MONGODBSPEC4_2.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC4_2_MONGOINFRA
_MONGODBSPEC4_4_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2._MONGODCONFIG4_4
_MONGODBSPEC4_4_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_MONGOD.containing_type = _MONGODBSPEC4_4
_MONGODBSPEC4_4_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2._MONGOCFGCONFIG4_4
_MONGODBSPEC4_4_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_MONGOCFG.containing_type = _MONGODBSPEC4_4
_MONGODBSPEC4_4_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2._MONGOSCONFIG4_4
_MONGODBSPEC4_4_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_MONGOS.containing_type = _MONGODBSPEC4_4
_MONGODBSPEC4_4_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2._MONGOSCONFIG4_4
_MONGODBSPEC4_4_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2._MONGOCFGCONFIG4_4
_MONGODBSPEC4_4_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_MONGOINFRA.containing_type = _MONGODBSPEC4_4
_MONGODBSPEC4_4.fields_by_name['mongod'].message_type = _MONGODBSPEC4_4_MONGOD
_MONGODBSPEC4_4.fields_by_name['mongocfg'].message_type = _MONGODBSPEC4_4_MONGOCFG
_MONGODBSPEC4_4.fields_by_name['mongos'].message_type = _MONGODBSPEC4_4_MONGOS
_MONGODBSPEC4_4.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC4_4_MONGOINFRA
_MONGODBSPEC4_4_ENTERPRISE_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2._MONGODCONFIG4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_ENTERPRISE_MONGOD.containing_type = _MONGODBSPEC4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2._MONGOCFGCONFIG4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_ENTERPRISE_MONGOCFG.containing_type = _MONGODBSPEC4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2._MONGOSCONFIG4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_ENTERPRISE_MONGOS.containing_type = _MONGODBSPEC4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2._MONGOSCONFIG4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2._MONGOCFGCONFIG4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA.containing_type = _MONGODBSPEC4_4_ENTERPRISE
_MONGODBSPEC4_4_ENTERPRISE.fields_by_name['mongod'].message_type = _MONGODBSPEC4_4_ENTERPRISE_MONGOD
_MONGODBSPEC4_4_ENTERPRISE.fields_by_name['mongocfg'].message_type = _MONGODBSPEC4_4_ENTERPRISE_MONGOCFG
_MONGODBSPEC4_4_ENTERPRISE.fields_by_name['mongos'].message_type = _MONGODBSPEC4_4_ENTERPRISE_MONGOS
_MONGODBSPEC4_4_ENTERPRISE.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA
_MONGODBSPEC5_0_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2._MONGODCONFIG5_0
_MONGODBSPEC5_0_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_MONGOD.containing_type = _MONGODBSPEC5_0
_MONGODBSPEC5_0_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2._MONGOCFGCONFIG5_0
_MONGODBSPEC5_0_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_MONGOCFG.containing_type = _MONGODBSPEC5_0
_MONGODBSPEC5_0_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2._MONGOSCONFIG5_0
_MONGODBSPEC5_0_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_MONGOS.containing_type = _MONGODBSPEC5_0
_MONGODBSPEC5_0_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2._MONGOSCONFIG5_0
_MONGODBSPEC5_0_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2._MONGOCFGCONFIG5_0
_MONGODBSPEC5_0_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_MONGOINFRA.containing_type = _MONGODBSPEC5_0
_MONGODBSPEC5_0.fields_by_name['mongod'].message_type = _MONGODBSPEC5_0_MONGOD
_MONGODBSPEC5_0.fields_by_name['mongocfg'].message_type = _MONGODBSPEC5_0_MONGOCFG
_MONGODBSPEC5_0.fields_by_name['mongos'].message_type = _MONGODBSPEC5_0_MONGOS
_MONGODBSPEC5_0.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC5_0_MONGOINFRA
_MONGODBSPEC5_0_ENTERPRISE_MONGOD.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2._MONGODCONFIG5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOD.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_ENTERPRISE_MONGOD.containing_type = _MONGODBSPEC5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOCFG.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2._MONGOCFGCONFIG5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOCFG.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_ENTERPRISE_MONGOCFG.containing_type = _MONGODBSPEC5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOS.fields_by_name['config'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2._MONGOSCONFIG5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOS.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_ENTERPRISE_MONGOS.containing_type = _MONGODBSPEC5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA.fields_by_name['config_mongos'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2._MONGOSCONFIG5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA.fields_by_name['config_mongocfg'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2._MONGOCFGCONFIG5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._RESOURCES
_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA.containing_type = _MONGODBSPEC5_0_ENTERPRISE
_MONGODBSPEC5_0_ENTERPRISE.fields_by_name['mongod'].message_type = _MONGODBSPEC5_0_ENTERPRISE_MONGOD
_MONGODBSPEC5_0_ENTERPRISE.fields_by_name['mongocfg'].message_type = _MONGODBSPEC5_0_ENTERPRISE_MONGOCFG
_MONGODBSPEC5_0_ENTERPRISE.fields_by_name['mongos'].message_type = _MONGODBSPEC5_0_ENTERPRISE_MONGOS
_MONGODBSPEC5_0_ENTERPRISE.fields_by_name['mongoinfra'].message_type = _MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA
_CONFIGSPEC.fields_by_name['mongodb_spec_3_6'].message_type = _MONGODBSPEC3_6
_CONFIGSPEC.fields_by_name['mongodb_spec_4_0'].message_type = _MONGODBSPEC4_0
_CONFIGSPEC.fields_by_name['mongodb_spec_4_2'].message_type = _MONGODBSPEC4_2
_CONFIGSPEC.fields_by_name['mongodb_spec_4_4'].message_type = _MONGODBSPEC4_4
_CONFIGSPEC.fields_by_name['mongodb_spec_5_0'].message_type = _MONGODBSPEC5_0
_CONFIGSPEC.fields_by_name['mongodb_spec_4_4_enterprise'].message_type = _MONGODBSPEC4_4_ENTERPRISE
_CONFIGSPEC.fields_by_name['mongodb_spec_5_0_enterprise'].message_type = _MONGODBSPEC5_0_ENTERPRISE
_CONFIGSPEC.fields_by_name['backup_window_start'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
_CONFIGSPEC.fields_by_name['backup_retain_period_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONFIGSPEC.fields_by_name['access'].message_type = yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._ACCESS
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_3_6'])
_CONFIGSPEC.fields_by_name['mongodb_spec_3_6'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_4_0'])
_CONFIGSPEC.fields_by_name['mongodb_spec_4_0'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_4_2'])
_CONFIGSPEC.fields_by_name['mongodb_spec_4_2'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_4_4'])
_CONFIGSPEC.fields_by_name['mongodb_spec_4_4'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_5_0'])
_CONFIGSPEC.fields_by_name['mongodb_spec_5_0'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_4_4_enterprise'])
_CONFIGSPEC.fields_by_name['mongodb_spec_4_4_enterprise'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
_CONFIGSPEC.oneofs_by_name['mongodb_spec'].fields.append(
  _CONFIGSPEC.fields_by_name['mongodb_spec_5_0_enterprise'])
_CONFIGSPEC.fields_by_name['mongodb_spec_5_0_enterprise'].containing_oneof = _CONFIGSPEC.oneofs_by_name['mongodb_spec']
DESCRIPTOR.message_types_by_name['GetClusterRequest'] = _GETCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateClusterRequest'] = _CREATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateClusterMetadata'] = _CREATECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterMetadata'] = _UPDATECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterMetadata'] = _DELETECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['StartClusterRequest'] = _STARTCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['StartClusterMetadata'] = _STARTCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['StopClusterRequest'] = _STOPCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['StopClusterMetadata'] = _STOPCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['MoveClusterRequest'] = _MOVECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['MoveClusterMetadata'] = _MOVECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['BackupClusterRequest'] = _BACKUPCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['BackupClusterMetadata'] = _BACKUPCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['RestoreClusterRequest'] = _RESTORECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['RestoreClusterMetadata'] = _RESTORECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['RescheduleMaintenanceRequest'] = _RESCHEDULEMAINTENANCEREQUEST
DESCRIPTOR.message_types_by_name['RescheduleMaintenanceMetadata'] = _RESCHEDULEMAINTENANCEMETADATA
DESCRIPTOR.message_types_by_name['LogRecord'] = _LOGRECORD
DESCRIPTOR.message_types_by_name['ListClusterLogsRequest'] = _LISTCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterLogsResponse'] = _LISTCLUSTERLOGSRESPONSE
DESCRIPTOR.message_types_by_name['StreamLogRecord'] = _STREAMLOGRECORD
DESCRIPTOR.message_types_by_name['StreamClusterLogsRequest'] = _STREAMCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterOperationsRequest'] = _LISTCLUSTEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterOperationsResponse'] = _LISTCLUSTEROPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListClusterBackupsRequest'] = _LISTCLUSTERBACKUPSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterBackupsResponse'] = _LISTCLUSTERBACKUPSRESPONSE
DESCRIPTOR.message_types_by_name['ListClusterHostsRequest'] = _LISTCLUSTERHOSTSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterHostsResponse'] = _LISTCLUSTERHOSTSRESPONSE
DESCRIPTOR.message_types_by_name['AddClusterHostsRequest'] = _ADDCLUSTERHOSTSREQUEST
DESCRIPTOR.message_types_by_name['AddClusterHostsMetadata'] = _ADDCLUSTERHOSTSMETADATA
DESCRIPTOR.message_types_by_name['DeleteClusterHostsRequest'] = _DELETECLUSTERHOSTSREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterHostsMetadata'] = _DELETECLUSTERHOSTSMETADATA
DESCRIPTOR.message_types_by_name['EnableClusterShardingRequest'] = _ENABLECLUSTERSHARDINGREQUEST
DESCRIPTOR.message_types_by_name['EnableClusterShardingMetadata'] = _ENABLECLUSTERSHARDINGMETADATA
DESCRIPTOR.message_types_by_name['GetClusterShardRequest'] = _GETCLUSTERSHARDREQUEST
DESCRIPTOR.message_types_by_name['ListClusterShardsRequest'] = _LISTCLUSTERSHARDSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterShardsResponse'] = _LISTCLUSTERSHARDSRESPONSE
DESCRIPTOR.message_types_by_name['AddClusterShardRequest'] = _ADDCLUSTERSHARDREQUEST
DESCRIPTOR.message_types_by_name['AddClusterShardMetadata'] = _ADDCLUSTERSHARDMETADATA
DESCRIPTOR.message_types_by_name['DeleteClusterShardRequest'] = _DELETECLUSTERSHARDREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterShardMetadata'] = _DELETECLUSTERSHARDMETADATA
DESCRIPTOR.message_types_by_name['ResetupHostsRequest'] = _RESETUPHOSTSREQUEST
DESCRIPTOR.message_types_by_name['ResetupHostsMetadata'] = _RESETUPHOSTSMETADATA
DESCRIPTOR.message_types_by_name['RestartHostsRequest'] = _RESTARTHOSTSREQUEST
DESCRIPTOR.message_types_by_name['RestartHostsMetadata'] = _RESTARTHOSTSMETADATA
DESCRIPTOR.message_types_by_name['StepdownHostsRequest'] = _STEPDOWNHOSTSREQUEST
DESCRIPTOR.message_types_by_name['StepdownHostsMetadata'] = _STEPDOWNHOSTSMETADATA
DESCRIPTOR.message_types_by_name['HostSpec'] = _HOSTSPEC
DESCRIPTOR.message_types_by_name['MongodbSpec3_6'] = _MONGODBSPEC3_6
DESCRIPTOR.message_types_by_name['MongodbSpec4_0'] = _MONGODBSPEC4_0
DESCRIPTOR.message_types_by_name['MongodbSpec4_2'] = _MONGODBSPEC4_2
DESCRIPTOR.message_types_by_name['MongodbSpec4_4'] = _MONGODBSPEC4_4
DESCRIPTOR.message_types_by_name['MongodbSpec4_4_enterprise'] = _MONGODBSPEC4_4_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongodbSpec5_0'] = _MONGODBSPEC5_0
DESCRIPTOR.message_types_by_name['MongodbSpec5_0_enterprise'] = _MONGODBSPEC5_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['ConfigSpec'] = _CONFIGSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetClusterRequest = _reflection.GeneratedProtocolMessageType('GetClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.GetClusterRequest)
  })
_sym_db.RegisterMessage(GetClusterRequest)

ListClustersRequest = _reflection.GeneratedProtocolMessageType('ListClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClustersRequest)
  })
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType('ListClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClustersResponse)
  })
_sym_db.RegisterMessage(ListClustersResponse)

CreateClusterRequest = _reflection.GeneratedProtocolMessageType('CreateClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.CreateClusterRequest)
  })
_sym_db.RegisterMessage(CreateClusterRequest)
_sym_db.RegisterMessage(CreateClusterRequest.LabelsEntry)

CreateClusterMetadata = _reflection.GeneratedProtocolMessageType('CreateClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.CreateClusterMetadata)
  })
_sym_db.RegisterMessage(CreateClusterMetadata)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest)
  })
_sym_db.RegisterMessage(UpdateClusterRequest)
_sym_db.RegisterMessage(UpdateClusterRequest.LabelsEntry)

UpdateClusterMetadata = _reflection.GeneratedProtocolMessageType('UpdateClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.UpdateClusterMetadata)
  })
_sym_db.RegisterMessage(UpdateClusterMetadata)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.DeleteClusterRequest)
  })
_sym_db.RegisterMessage(DeleteClusterRequest)

DeleteClusterMetadata = _reflection.GeneratedProtocolMessageType('DeleteClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.DeleteClusterMetadata)
  })
_sym_db.RegisterMessage(DeleteClusterMetadata)

StartClusterRequest = _reflection.GeneratedProtocolMessageType('StartClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StartClusterRequest)
  })
_sym_db.RegisterMessage(StartClusterRequest)

StartClusterMetadata = _reflection.GeneratedProtocolMessageType('StartClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STARTCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StartClusterMetadata)
  })
_sym_db.RegisterMessage(StartClusterMetadata)

StopClusterRequest = _reflection.GeneratedProtocolMessageType('StopClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StopClusterRequest)
  })
_sym_db.RegisterMessage(StopClusterRequest)

StopClusterMetadata = _reflection.GeneratedProtocolMessageType('StopClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StopClusterMetadata)
  })
_sym_db.RegisterMessage(StopClusterMetadata)

MoveClusterRequest = _reflection.GeneratedProtocolMessageType('MoveClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MoveClusterRequest)
  })
_sym_db.RegisterMessage(MoveClusterRequest)

MoveClusterMetadata = _reflection.GeneratedProtocolMessageType('MoveClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MoveClusterMetadata)
  })
_sym_db.RegisterMessage(MoveClusterMetadata)

BackupClusterRequest = _reflection.GeneratedProtocolMessageType('BackupClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.BackupClusterRequest)
  })
_sym_db.RegisterMessage(BackupClusterRequest)

BackupClusterMetadata = _reflection.GeneratedProtocolMessageType('BackupClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.BackupClusterMetadata)
  })
_sym_db.RegisterMessage(BackupClusterMetadata)

RestoreClusterRequest = _reflection.GeneratedProtocolMessageType('RestoreClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESTORECLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.LabelsEntry)
    })
  ,

  'RecoveryTargetSpec' : _reflection.GeneratedProtocolMessageType('RecoveryTargetSpec', (_message.Message,), {
    'DESCRIPTOR' : _RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.RecoveryTargetSpec)
    })
  ,
  'DESCRIPTOR' : _RESTORECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest)
  })
_sym_db.RegisterMessage(RestoreClusterRequest)
_sym_db.RegisterMessage(RestoreClusterRequest.LabelsEntry)
_sym_db.RegisterMessage(RestoreClusterRequest.RecoveryTargetSpec)

RestoreClusterMetadata = _reflection.GeneratedProtocolMessageType('RestoreClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESTORECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RestoreClusterMetadata)
  })
_sym_db.RegisterMessage(RestoreClusterMetadata)

RescheduleMaintenanceRequest = _reflection.GeneratedProtocolMessageType('RescheduleMaintenanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESCHEDULEMAINTENANCEREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest)
  })
_sym_db.RegisterMessage(RescheduleMaintenanceRequest)

RescheduleMaintenanceMetadata = _reflection.GeneratedProtocolMessageType('RescheduleMaintenanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESCHEDULEMAINTENANCEMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceMetadata)
  })
_sym_db.RegisterMessage(RescheduleMaintenanceMetadata)

LogRecord = _reflection.GeneratedProtocolMessageType('LogRecord', (_message.Message,), {

  'MessageEntry' : _reflection.GeneratedProtocolMessageType('MessageEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGRECORD_MESSAGEENTRY,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.LogRecord.MessageEntry)
    })
  ,
  'DESCRIPTOR' : _LOGRECORD,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.LogRecord)
  })
_sym_db.RegisterMessage(LogRecord)
_sym_db.RegisterMessage(LogRecord.MessageEntry)

ListClusterLogsRequest = _reflection.GeneratedProtocolMessageType('ListClusterLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERLOGSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest)
  })
_sym_db.RegisterMessage(ListClusterLogsRequest)

ListClusterLogsResponse = _reflection.GeneratedProtocolMessageType('ListClusterLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERLOGSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterLogsResponse)
  })
_sym_db.RegisterMessage(ListClusterLogsResponse)

StreamLogRecord = _reflection.GeneratedProtocolMessageType('StreamLogRecord', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLOGRECORD,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StreamLogRecord)
  })
_sym_db.RegisterMessage(StreamLogRecord)

StreamClusterLogsRequest = _reflection.GeneratedProtocolMessageType('StreamClusterLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCLUSTERLOGSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest)
  })
_sym_db.RegisterMessage(StreamClusterLogsRequest)

ListClusterOperationsRequest = _reflection.GeneratedProtocolMessageType('ListClusterOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest)
  })
_sym_db.RegisterMessage(ListClusterOperationsRequest)

ListClusterOperationsResponse = _reflection.GeneratedProtocolMessageType('ListClusterOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterOperationsResponse)
  })
_sym_db.RegisterMessage(ListClusterOperationsResponse)

ListClusterBackupsRequest = _reflection.GeneratedProtocolMessageType('ListClusterBackupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERBACKUPSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest)
  })
_sym_db.RegisterMessage(ListClusterBackupsRequest)

ListClusterBackupsResponse = _reflection.GeneratedProtocolMessageType('ListClusterBackupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERBACKUPSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterBackupsResponse)
  })
_sym_db.RegisterMessage(ListClusterBackupsResponse)

ListClusterHostsRequest = _reflection.GeneratedProtocolMessageType('ListClusterHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest)
  })
_sym_db.RegisterMessage(ListClusterHostsRequest)

ListClusterHostsResponse = _reflection.GeneratedProtocolMessageType('ListClusterHostsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERHOSTSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterHostsResponse)
  })
_sym_db.RegisterMessage(ListClusterHostsResponse)

AddClusterHostsRequest = _reflection.GeneratedProtocolMessageType('AddClusterHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDCLUSTERHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.AddClusterHostsRequest)
  })
_sym_db.RegisterMessage(AddClusterHostsRequest)

AddClusterHostsMetadata = _reflection.GeneratedProtocolMessageType('AddClusterHostsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDCLUSTERHOSTSMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.AddClusterHostsMetadata)
  })
_sym_db.RegisterMessage(AddClusterHostsMetadata)

DeleteClusterHostsRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsRequest)
  })
_sym_db.RegisterMessage(DeleteClusterHostsRequest)

DeleteClusterHostsMetadata = _reflection.GeneratedProtocolMessageType('DeleteClusterHostsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERHOSTSMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsMetadata)
  })
_sym_db.RegisterMessage(DeleteClusterHostsMetadata)

EnableClusterShardingRequest = _reflection.GeneratedProtocolMessageType('EnableClusterShardingRequest', (_message.Message,), {

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _ENABLECLUSTERSHARDINGREQUEST_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _ENABLECLUSTERSHARDINGREQUEST_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _ENABLECLUSTERSHARDINGREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest)
  })
_sym_db.RegisterMessage(EnableClusterShardingRequest)
_sym_db.RegisterMessage(EnableClusterShardingRequest.MongoCfg)
_sym_db.RegisterMessage(EnableClusterShardingRequest.Mongos)
_sym_db.RegisterMessage(EnableClusterShardingRequest.MongoInfra)

EnableClusterShardingMetadata = _reflection.GeneratedProtocolMessageType('EnableClusterShardingMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ENABLECLUSTERSHARDINGMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.EnableClusterShardingMetadata)
  })
_sym_db.RegisterMessage(EnableClusterShardingMetadata)

GetClusterShardRequest = _reflection.GeneratedProtocolMessageType('GetClusterShardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERSHARDREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.GetClusterShardRequest)
  })
_sym_db.RegisterMessage(GetClusterShardRequest)

ListClusterShardsRequest = _reflection.GeneratedProtocolMessageType('ListClusterShardsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSHARDSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest)
  })
_sym_db.RegisterMessage(ListClusterShardsRequest)

ListClusterShardsResponse = _reflection.GeneratedProtocolMessageType('ListClusterShardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSHARDSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ListClusterShardsResponse)
  })
_sym_db.RegisterMessage(ListClusterShardsResponse)

AddClusterShardRequest = _reflection.GeneratedProtocolMessageType('AddClusterShardRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDCLUSTERSHARDREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest)
  })
_sym_db.RegisterMessage(AddClusterShardRequest)

AddClusterShardMetadata = _reflection.GeneratedProtocolMessageType('AddClusterShardMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDCLUSTERSHARDMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.AddClusterShardMetadata)
  })
_sym_db.RegisterMessage(AddClusterShardMetadata)

DeleteClusterShardRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterShardRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERSHARDREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.DeleteClusterShardRequest)
  })
_sym_db.RegisterMessage(DeleteClusterShardRequest)

DeleteClusterShardMetadata = _reflection.GeneratedProtocolMessageType('DeleteClusterShardMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERSHARDMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.DeleteClusterShardMetadata)
  })
_sym_db.RegisterMessage(DeleteClusterShardMetadata)

ResetupHostsRequest = _reflection.GeneratedProtocolMessageType('ResetupHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETUPHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ResetupHostsRequest)
  })
_sym_db.RegisterMessage(ResetupHostsRequest)

ResetupHostsMetadata = _reflection.GeneratedProtocolMessageType('ResetupHostsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESETUPHOSTSMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ResetupHostsMetadata)
  })
_sym_db.RegisterMessage(ResetupHostsMetadata)

RestartHostsRequest = _reflection.GeneratedProtocolMessageType('RestartHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RestartHostsRequest)
  })
_sym_db.RegisterMessage(RestartHostsRequest)

RestartHostsMetadata = _reflection.GeneratedProtocolMessageType('RestartHostsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTHOSTSMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.RestartHostsMetadata)
  })
_sym_db.RegisterMessage(RestartHostsMetadata)

StepdownHostsRequest = _reflection.GeneratedProtocolMessageType('StepdownHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STEPDOWNHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StepdownHostsRequest)
  })
_sym_db.RegisterMessage(StepdownHostsRequest)

StepdownHostsMetadata = _reflection.GeneratedProtocolMessageType('StepdownHostsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STEPDOWNHOSTSMETADATA,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.StepdownHostsMetadata)
  })
_sym_db.RegisterMessage(StepdownHostsMetadata)

HostSpec = _reflection.GeneratedProtocolMessageType('HostSpec', (_message.Message,), {
  'DESCRIPTOR' : _HOSTSPEC,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.HostSpec)
  })
_sym_db.RegisterMessage(HostSpec)

MongodbSpec3_6 = _reflection.GeneratedProtocolMessageType('MongodbSpec3_6', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC3_6_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC3_6_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC3_6_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC3_6_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC3_6,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6)
  })
_sym_db.RegisterMessage(MongodbSpec3_6)
_sym_db.RegisterMessage(MongodbSpec3_6.Mongod)
_sym_db.RegisterMessage(MongodbSpec3_6.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec3_6.Mongos)
_sym_db.RegisterMessage(MongodbSpec3_6.MongoInfra)

MongodbSpec4_0 = _reflection.GeneratedProtocolMessageType('MongodbSpec4_0', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_0_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_0_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_0_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_0_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC4_0,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0)
  })
_sym_db.RegisterMessage(MongodbSpec4_0)
_sym_db.RegisterMessage(MongodbSpec4_0.Mongod)
_sym_db.RegisterMessage(MongodbSpec4_0.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec4_0.Mongos)
_sym_db.RegisterMessage(MongodbSpec4_0.MongoInfra)

MongodbSpec4_2 = _reflection.GeneratedProtocolMessageType('MongodbSpec4_2', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_2_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_2_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_2_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_2_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2)
  })
_sym_db.RegisterMessage(MongodbSpec4_2)
_sym_db.RegisterMessage(MongodbSpec4_2.Mongod)
_sym_db.RegisterMessage(MongodbSpec4_2.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec4_2.Mongos)
_sym_db.RegisterMessage(MongodbSpec4_2.MongoInfra)

MongodbSpec4_4 = _reflection.GeneratedProtocolMessageType('MongodbSpec4_4', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC4_4,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4)
  })
_sym_db.RegisterMessage(MongodbSpec4_4)
_sym_db.RegisterMessage(MongodbSpec4_4.Mongod)
_sym_db.RegisterMessage(MongodbSpec4_4.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec4_4.Mongos)
_sym_db.RegisterMessage(MongodbSpec4_4.MongoInfra)

MongodbSpec4_4_enterprise = _reflection.GeneratedProtocolMessageType('MongodbSpec4_4_enterprise', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_ENTERPRISE_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_ENTERPRISE_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_ENTERPRISE_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC4_4_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise)
  })
_sym_db.RegisterMessage(MongodbSpec4_4_enterprise)
_sym_db.RegisterMessage(MongodbSpec4_4_enterprise.Mongod)
_sym_db.RegisterMessage(MongodbSpec4_4_enterprise.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec4_4_enterprise.Mongos)
_sym_db.RegisterMessage(MongodbSpec4_4_enterprise.MongoInfra)

MongodbSpec5_0 = _reflection.GeneratedProtocolMessageType('MongodbSpec5_0', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC5_0,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0)
  })
_sym_db.RegisterMessage(MongodbSpec5_0)
_sym_db.RegisterMessage(MongodbSpec5_0.Mongod)
_sym_db.RegisterMessage(MongodbSpec5_0.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec5_0.Mongos)
_sym_db.RegisterMessage(MongodbSpec5_0.MongoInfra)

MongodbSpec5_0_enterprise = _reflection.GeneratedProtocolMessageType('MongodbSpec5_0_enterprise', (_message.Message,), {

  'Mongod' : _reflection.GeneratedProtocolMessageType('Mongod', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_ENTERPRISE_MONGOD,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongod)
    })
  ,

  'MongoCfg' : _reflection.GeneratedProtocolMessageType('MongoCfg', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_ENTERPRISE_MONGOCFG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoCfg)
    })
  ,

  'Mongos' : _reflection.GeneratedProtocolMessageType('Mongos', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_ENTERPRISE_MONGOS,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongos)
    })
  ,

  'MongoInfra' : _reflection.GeneratedProtocolMessageType('MongoInfra', (_message.Message,), {
    'DESCRIPTOR' : _MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra)
    })
  ,
  'DESCRIPTOR' : _MONGODBSPEC5_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise)
  })
_sym_db.RegisterMessage(MongodbSpec5_0_enterprise)
_sym_db.RegisterMessage(MongodbSpec5_0_enterprise.Mongod)
_sym_db.RegisterMessage(MongodbSpec5_0_enterprise.MongoCfg)
_sym_db.RegisterMessage(MongodbSpec5_0_enterprise.Mongos)
_sym_db.RegisterMessage(MongodbSpec5_0_enterprise.MongoInfra)

ConfigSpec = _reflection.GeneratedProtocolMessageType('ConfigSpec', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGSPEC,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ConfigSpec)
  })
_sym_db.RegisterMessage(ConfigSpec)


DESCRIPTOR._options = None
_GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
_CREATECLUSTERREQUEST_LABELSENTRY._options = None
_CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
_CREATECLUSTERREQUEST.fields_by_name['name']._options = None
_CREATECLUSTERREQUEST.fields_by_name['description']._options = None
_CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
_CREATECLUSTERREQUEST.fields_by_name['environment']._options = None
_CREATECLUSTERREQUEST.fields_by_name['config_spec']._options = None
_CREATECLUSTERREQUEST.fields_by_name['database_specs']._options = None
_CREATECLUSTERREQUEST.fields_by_name['user_specs']._options = None
_CREATECLUSTERREQUEST.fields_by_name['host_specs']._options = None
_CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
_UPDATECLUSTERREQUEST_LABELSENTRY._options = None
_UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
_DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
_BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_RESTORECLUSTERREQUEST_LABELSENTRY._options = None
_RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC.fields_by_name['timestamp']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['name']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['description']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['labels']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['environment']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['config_spec']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['host_specs']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['network_id']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['folder_id']._options = None
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._options = None
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._options = None
_LOGRECORD_MESSAGEENTRY._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
_STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
_STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._options = None
_STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
_LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
_ADDCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_ADDCLUSTERHOSTSREQUEST.fields_by_name['host_specs']._options = None
_DELETECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_DELETECLUSTERHOSTSREQUEST.fields_by_name['host_names']._options = None
_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG.fields_by_name['resources']._options = None
_ENABLECLUSTERSHARDINGREQUEST_MONGOS.fields_by_name['resources']._options = None
_ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA.fields_by_name['resources']._options = None
_ENABLECLUSTERSHARDINGREQUEST.fields_by_name['cluster_id']._options = None
_ENABLECLUSTERSHARDINGREQUEST.fields_by_name['host_specs']._options = None
_GETCLUSTERSHARDREQUEST.fields_by_name['cluster_id']._options = None
_GETCLUSTERSHARDREQUEST.fields_by_name['shard_name']._options = None
_LISTCLUSTERSHARDSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERSHARDSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERSHARDSREQUEST.fields_by_name['page_token']._options = None
_ADDCLUSTERSHARDREQUEST.fields_by_name['cluster_id']._options = None
_ADDCLUSTERSHARDREQUEST.fields_by_name['shard_name']._options = None
_ADDCLUSTERSHARDREQUEST.fields_by_name['host_specs']._options = None
_DELETECLUSTERSHARDREQUEST.fields_by_name['cluster_id']._options = None
_DELETECLUSTERSHARDREQUEST.fields_by_name['shard_name']._options = None
_RESETUPHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_RESETUPHOSTSREQUEST.fields_by_name['host_names']._options = None
_RESTARTHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_RESTARTHOSTSREQUEST.fields_by_name['host_names']._options = None
_STEPDOWNHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_STEPDOWNHOSTSREQUEST.fields_by_name['host_names']._options = None
_HOSTSPEC.fields_by_name['zone_id']._options = None
_HOSTSPEC.fields_by_name['subnet_id']._options = None
_HOSTSPEC.fields_by_name['shard_name']._options = None
_CONFIGSPEC.fields_by_name['backup_retain_period_days']._options = None

_CLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='ClusterService',
  full_name='yandex.cloud.mdb.mongodb.v1.ClusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=16834,
  serialized_end=21944,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._CLUSTER,
    serialized_options=b'\202\323\344\223\002+\022)/managed-mongodb/v1/clusters/{cluster_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCLUSTERSREQUEST,
    output_type=_LISTCLUSTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/managed-mongodb/v1/clusters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!\"\034/managed-mongodb/v1/clusters:\001*\262\322* \n\025CreateClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.2)/managed-mongodb/v1/clusters/{cluster_id}:\001*\262\322* \n\025UpdateClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+*)/managed-mongodb/v1/clusters/{cluster_id}\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Start',
    index=5,
    containing_service=None,
    input_type=_STARTCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021\"//managed-mongodb/v1/clusters/{cluster_id}:start\262\322*\037\n\024StartClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Stop',
    index=6,
    containing_service=None,
    input_type=_STOPCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0020\"./managed-mongodb/v1/clusters/{cluster_id}:stop\262\322*\036\n\023StopClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Move',
    index=7,
    containing_service=None,
    input_type=_MOVECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./managed-mongodb/v1/clusters/{cluster_id}:move:\001*\262\322*\036\n\023MoveClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Backup',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Backup',
    index=8,
    containing_service=None,
    input_type=_BACKUPCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0022\"0/managed-mongodb/v1/clusters/{cluster_id}:backup\262\322* \n\025BackupClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Restore',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.Restore',
    index=9,
    containing_service=None,
    input_type=_RESTORECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)\"$/managed-mongodb/v1/clusters:restore:\001*\262\322*!\n\026RestoreClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RescheduleMaintenance',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.RescheduleMaintenance',
    index=10,
    containing_service=None,
    input_type=_RESCHEDULEMAINTENANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002D\"?/managed-mongodb/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogs',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.ListLogs',
    index=11,
    containing_service=None,
    input_type=_LISTCLUSTERLOGSREQUEST,
    output_type=_LISTCLUSTERLOGSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./managed-mongodb/v1/clusters/{cluster_id}:logs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamLogs',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.StreamLogs',
    index=12,
    containing_service=None,
    input_type=_STREAMCLUSTERLOGSREQUEST,
    output_type=_STREAMLOGRECORD,
    serialized_options=b'\202\323\344\223\0027\0225/managed-mongodb/v1/clusters/{cluster_id}:stream_logs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.ListOperations',
    index=13,
    containing_service=None,
    input_type=_LISTCLUSTEROPERATIONSREQUEST,
    output_type=_LISTCLUSTEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/managed-mongodb/v1/clusters/{cluster_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListBackups',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.ListBackups',
    index=14,
    containing_service=None,
    input_type=_LISTCLUSTERBACKUPSREQUEST,
    output_type=_LISTCLUSTERBACKUPSRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/managed-mongodb/v1/clusters/{cluster_id}/backups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListHosts',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.ListHosts',
    index=15,
    containing_service=None,
    input_type=_LISTCLUSTERHOSTSREQUEST,
    output_type=_LISTCLUSTERHOSTSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//managed-mongodb/v1/clusters/{cluster_id}/hosts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddHosts',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.AddHosts',
    index=16,
    containing_service=None,
    input_type=_ADDCLUSTERHOSTSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchCreate:\001*\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteHosts',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.DeleteHosts',
    index=17,
    containing_service=None,
    input_type=_DELETECLUSTERHOSTSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchDelete:\001*\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableSharding',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.EnableSharding',
    index=18,
    containing_service=None,
    input_type=_ENABLECLUSTERSHARDINGREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=\"8/managed-mongodb/v1/clusters/{cluster_id}:enableSharding:\001*\262\322*6\n\035EnableClusterShardingMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetShard',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.GetShard',
    index=19,
    containing_service=None,
    input_type=_GETCLUSTERSHARDREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2._SHARD,
    serialized_options=b'\202\323\344\223\002?\022=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListShards',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.ListShards',
    index=20,
    containing_service=None,
    input_type=_LISTCLUSTERSHARDSREQUEST,
    output_type=_LISTCLUSTERSHARDSRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/managed-mongodb/v1/clusters/{cluster_id}/shards',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddShard',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.AddShard',
    index=21,
    containing_service=None,
    input_type=_ADDCLUSTERSHARDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0025\"0/managed-mongodb/v1/clusters/{cluster_id}/shards:\001*\262\322* \n\027AddClusterShardMetadata\022\005Shard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteShard',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.DeleteShard',
    index=22,
    containing_service=None,
    input_type=_DELETECLUSTERSHARDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?*=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}\262\322*3\n\032DeleteClusterShardMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetupHosts',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.ResetupHosts',
    index=23,
    containing_service=None,
    input_type=_RESETUPHOSTSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002;\"6/managed-mongodb/v1/clusters/{cluster_id}:resetupHosts:\001*\262\322*-\n\024ResetupHostsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RestartHosts',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.RestartHosts',
    index=24,
    containing_service=None,
    input_type=_RESTARTHOSTSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002;\"6/managed-mongodb/v1/clusters/{cluster_id}:restartHosts:\001*\262\322*-\n\024RestartHostsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StepdownHosts',
    full_name='yandex.cloud.mdb.mongodb.v1.ClusterService.StepdownHosts',
    index=25,
    containing_service=None,
    input_type=_STEPDOWNHOSTSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002<\"7/managed-mongodb/v1/clusters/{cluster_id}:stepdownHosts:\001*\262\322*.\n\025StepdownHostsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLUSTERSERVICE)

DESCRIPTOR.services_by_name['ClusterService'] = _CLUSTERSERVICE

# @@protoc_insertion_point(module_scope)
